@@ -54,6 +54,7 @@ class AsyncConsumer(AsyncWebsocketConsumer):
         return self.bindings_by_stream.get(stream)
 
     async def connect(self):
+        print(self.scope['user'])
         try:
             if inspect.iscoroutinefunction(self.get_user):
                 self.user = await self.get_user()
@@ -64,7 +65,7 @@ class AsyncConsumer(AsyncWebsocketConsumer):
                 self.bindings_by_class = {}
                 self.bindings_by_stream = {}
                 for bc in registered_binding_classes:
-                    binding = bc(self)
+                    binding = bc()
                     self.bindings_by_class[bc] = binding
                     self.bindings_by_stream[binding.stream] = binding
                 await self.subscribe('__all__')
